..
    Copyright (C) 2021 CERN.
    Copyright (C) 2019 Esteban J. Garcia Gabancho.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.0.0a2 (released 2022-09-12)

- Add auto_confirm, confirm user email address

Version 1.0.0a1 (released 2021-07-15)

- Marking strings for translation
- Adds german translation

Version 1.0.0a0 (released 2021-05-27)

- Module refactoring.

Version 0.1.0 (released TBD)

- Initial public release.
